<?php

/*
 * This file is part of Buckhill software repository.
 *
 * (c) Buckhill Ltd <development@buckhill.co.uk>
 *
 * This source file is subject to the Buckhill license that is bundled
 * with this source code in the file LICENSE.
 */

namespace Buckhill\Support\Noop;

use Buckhill\Support\Traits\DotNotationAccessorTrait;

class DotNotation
{
    use DotNotationAccessorTrait;

    protected $prop;
    protected $model;

    public function __construct($prop = null, $model = null)
    {
        $this->prop = $prop;
        $this->model = $model;
    }
}